<?php
/*
	vpn_ipsec.php
	part of m0n0wall (http://m0n0.ch/wall)
	part of pfSense

	Copyright (C) 2003-2005 Manuel Kasper <mk@neon1.net>.
	Copyright (C) 2008 Shrew Soft Inc
	Copyright (C) 2013-2015 Electric Sheep Fencing, LP
	All rights reserved.

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	1. Redistributions of source code must retain the above copyright notice,
	   this list of conditions and the following disclaimer.

	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
	AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
	AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
	OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
	SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
	CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
	POSSIBILITY OF SUCH DAMAGE.
*/

##|+PRIV
##|*IDENT=page-vpn-ipsec
##|*NAME=VPN: IPsec page
##|*DESCR=Allow access to the 'VPN: IPsec' page.
##|*MATCH=vpn_ipsec.php*
##|-PRIV

require("guiconfig.inc");
require_once("functions.inc");
require_once("filter.inc");
require_once("shaper.inc");
require_once("ipsec.inc");
require_once("vpn.inc");

if (!is_array($config['ipsec']['phase1']))
	$config['ipsec']['phase1'] = array();

if (!is_array($config['ipsec']['phase2']))
	$config['ipsec']['phase2'] = array();

$a_phase1 = &$config['ipsec']['phase1'];
$a_phase2 = &$config['ipsec']['phase2'];

$pconfig['enable'] = isset($config['ipsec']['enable']);

if ($_POST) {
	if ($_POST['apply']) {
		$retval = 0;
		$retval = vpn_ipsec_configure();
		/* reload the filter in the background */
		filter_configure();
		$savemsg = get_std_save_message($retval);
		if ($retval >= 0) {
			if (is_subsystem_dirty('ipsec'))
				clear_subsystem_dirty('ipsec');
		}
	} else if ($_POST['save']) {
		$pconfig = $_POST;

		$config['ipsec']['enable'] = $_POST['enable'] ? true : false;

		write_config();

		$retval = vpn_ipsec_configure();
	} else if (isset($_POST['del_x'])) {
		/* delete selected p1 entries */
		if (is_array($_POST['p1entry']) && count($_POST['p1entry'])) {
			foreach ($_POST['p1entry'] as $p1entrydel) {
				unset($a_phase1[$p1entrydel]);
			}
			if (write_config())
				mark_subsystem_dirty('ipsec');
		}
	} else if (isset($_POST['delp2_x'])) {
		/* delete selected p2 entries */
		if (is_array($_POST['p2entry']) && count($_POST['p2entry'])) {
			foreach ($_POST['p2entry'] as $p2entrydel) {
				unset($a_phase2[$p2entrydel]);
			}
			if (write_config())
				mark_subsystem_dirty('ipsec');
		}
	} else {
		/* yuck - IE won't send value attributes for image buttons, while Mozilla does - so we use .x/.y to find move button clicks instead... */

		// TODO: this. is. nasty.
		unset($delbtn, $delbtnp2, $movebtn, $movebtnp2, $togglebtn, $togglebtnp2);
		foreach ($_POST as $pn => $pd) {
			if (preg_match("/del_(\d+)/", $pn, $matches)) {
				$delbtn = $matches[1];
			} else if (preg_match("/delp2_(\d+)/", $pn, $matches)) {
				$delbtnp2 = $matches[1];
			} else if (preg_match("/move_(\d+)/", $pn, $matches)) {
				$movebtn = $matches[1];
			} else if (preg_match("/movep2_(\d+)/", $pn, $matches)) {
				$movebtnp2 = $matches[1];
			} else if (preg_match("/toggle_(\d+)/", $pn, $matches)) {
				$togglebtn = $matches[1];
			} else if (preg_match("/togglep2_(\d+)/", $pn, $matches)) {
				$togglebtnp2 = $matches[1];
			}
		}

		$save = 1;

		/* move selected p1 entries before this */
		if (isset($movebtn) && is_array($_POST['p1entry']) && count($_POST['p1entry'])) {
			$a_phase1_new = array();

			/* copy all p1 entries < $movebtn and not selected */
			for ($i = 0; $i < $movebtn; $i++) {
				if (!in_array($i, $_POST['p1entry']))
					$a_phase1_new[] = $a_phase1[$i];
			}

			/* copy all selected p1 entries */
			for ($i = 0; $i < count($a_phase1); $i++) {
				if ($i == $movebtn)
					continue;
				if (in_array($i, $_POST['p1entry']))
					$a_phase1_new[] = $a_phase1[$i];
			}

			/* copy $movebtn p1 entry */
			if ($movebtn < count($a_phase1))
				$a_phase1_new[] = $a_phase1[$movebtn];

			/* copy all p1 entries > $movebtn and not selected */
			for ($i = $movebtn+1; $i < count($a_phase1); $i++) {
				if (!in_array($i, $_POST['p1entry']))
					$a_phase1_new[] = $a_phase1[$i];
			}
			if (count($a_phase1_new) > 0)
				$a_phase1 = $a_phase1_new;

		} else if (isset($movebtnp2) && is_array($_POST['p2entry']) && count($_POST['p2entry'])) {
			/* move selected p2 entries before this */
			$a_phase2_new = array();

			/* copy all p2 entries < $movebtnp2 and not selected */
			for ($i = 0; $i < $movebtnp2; $i++) {
				if (!in_array($i, $_POST['p2entry']))
					$a_phase2_new[] = $a_phase2[$i];
			}

			/* copy all selected p2 entries */
			for ($i = 0; $i < count($a_phase2); $i++) {
				if ($i == $movebtnp2)
					continue;
				if (in_array($i, $_POST['p2entry']))
					$a_phase2_new[] = $a_phase2[$i];
			}

			/* copy $movebtnp2 p2 entry */
			if ($movebtnp2 < count($a_phase2))
				$a_phase2_new[] = $a_phase2[$movebtnp2];

			/* copy all p2 entries > $movebtnp2 and not selected */
			for ($i = $movebtnp2+1; $i < count($a_phase2); $i++) {
				if (!in_array($i, $_POST['p2entry']))
					$a_phase2_new[] = $a_phase2[$i];
			}
			if (count($a_phase2_new) > 0)
				$a_phase2 = $a_phase2_new;

		} else if (isset($togglebtn)) {
			if (isset($a_phase1[$togglebtn]['disabled']))
				unset($a_phase1[$togglebtn]['disabled']);
			else
				$a_phase1[$togglebtn]['disabled'] = true;

		} else if (isset($togglebtnp2)) {
			if (isset($a_phase2[$togglebtnp2]['disabled']))
				unset($a_phase2[$togglebtnp2]['disabled']);
			else
				$a_phase2[$togglebtnp2]['disabled'] = true;

		} else if (isset($delbtn)) {
			/* remove static route if interface is not WAN */
			if ($a_phase1[$delbtn]['interface'] != "wan")
				mwexec("/sbin/route delete -host {$a_phase1[$delbtn]['remote-gateway']}");

			/* remove all phase2 entries that match the ikeid */
			$ikeid = $a_phase1[$delbtn]['ikeid'];
			foreach ($a_phase2 as $p2index => $ph2tmp)
				if ($ph2tmp['ikeid'] == $ikeid) {
					unset($a_phase2[$p2index]);
				}

			unset($a_phase1[$delbtn]);

		} else if (isset($delbtnp2)) {
			unset($a_phase2[$delbtnp2]);

		} else
			$save = 0;

		if ($save === 1) {
			if (write_config())
				mark_subsystem_dirty('ipsec');
		}
	}
}

$pgtitle = array(gettext("VPN"),gettext("IPsec"));
$shortcut_section = "ipsec";

include("head.inc");

?>

<script type="text/javascript" src="/javascript/row_toggle.js"></script>

<?php

	if ($savemsg)
		print_info_box($savemsg);
	if ($pconfig['enable'] && is_subsystem_dirty('ipsec'))
		print_info_box_np(gettext("The IPsec tunnel configuration has been changed") . ".<br />" . gettext("You must apply the changes in order for them to take effect."));

	$tab_array = array();
	$tab_array[0] = array(gettext("Tunnels"), true, "vpn_ipsec.php");
	$tab_array[1] = array(gettext("Mobile clients"), false, "vpn_ipsec_mobile.php");
	$tab_array[2] = array(gettext("Pre-Shared Keys"), false, "vpn_ipsec_keys.php");
	$tab_array[3] = array(gettext("Advanced Settings"), false, "vpn_ipsec_settings.php");
	display_top_tabs($tab_array, false, 'pills');

	require('classes/Form.class.php');
	$form = new Form;

	$section = new Form_Section('Enable IPsec');
	$section->addInput(new Form_Checkbox(
		'enable',
		'Enable',
		'Enable IPsec',
		$pconfig['enable']
	));

	$form->add($section);

	print $form;

?>

<form method="post">
<div class="table-responsive">
	<table class="table table-striped table-hover">
		<thead>
			<tr>
				<th class="list">&nbsp;</th>
				<th class="list">&nbsp;</th>
				<th class="listhdrr"><?=gettext("IKE"); ?></th>
				<th class="listhdrr"><?=gettext("Remote Gateway"); ?></th>
				<th class="listhdrr"><?=gettext("Mode"); ?></th>
				<th class="listhdrr"><?=gettext("P1 Protocol"); ?></th>
				<th class="listhdrr"><?=gettext("P1 Transforms"); ?></th>
				<th class="listhdrr"><?=gettext("P1 Description"); ?></th>
				<th class="list"></th>
			</tr>
		</thead>
		<tbody>
<?php $i = 0; foreach ($a_phase1 as $ph1ent): ?>
<?php
	$iconfn = "pass";

	$entryStatus = (isset($ph1ent['disabled']) ? 'disabled' : 'enabled');

	if ($entryStatus == 'disabled') {
		$iconfn .= "_d";
	}
?>
	<tr id="fr<?=$i?>" ondblclick="document.location='vpn_ipsec_phase1.php?p1index=<?=$i?>'" class="<?= $entryStatus ?>">
		<td>
			<input type="checkbox" id="frc<?=$i?>" name="p1entry[]" value="<?=$i?>" onclick="fr_bgcolor('<?=$i?>')" />
		</td>
		<td>
			<button value="toggle_<?=$i?>" name="toggle_<?=$i?>" title="<?=gettext("click to toggle enabled/disabled status")?>" class="btn btn-xs btn-default" type="submit"><?= ($entryStatus == 'disabled' ? 'enable' : 'disable') ?></button>
		</td>
		<td onclick="fr_toggle(<?=$i?>)" id="frd<?=$i?>">
<?php
			if (empty($ph1ent['iketype']) || $ph1ent['iketype'] == "ikev1")
				echo "V1";
			else
				echo "V2";
?>
		</td>
		<td onclick="fr_toggle(<?=$i?>)" id="frd<?=$i?>">
<?php
			if ($ph1ent['interface']) {
				$iflabels = get_configured_interface_with_descr();

				$carplist = get_configured_carp_interface_list();
				foreach ($carplist as $cif => $carpip)
					$iflabels[$cif] = $carpip." (".get_vip_descr($carpip).")";

				$aliaslist = get_configured_ip_aliases_list();
				foreach ($aliaslist as $aliasip => $aliasif)
					$iflabels[$aliasip] = $aliasip." (".get_vip_descr($aliasip).")";

				$grouplist = return_gateway_groups_array();
				foreach ($grouplist as $name => $group) {
					if($group[0]['vip'] != "")
						$vipif = $group[0]['vip'];
					else
						$vipif = $group[0]['int'];
					$iflabels[$name] = "GW Group {$name}";
				}
				$if = htmlspecialchars($iflabels[$ph1ent['interface']]);
			}
			else
				$if = "WAN";

			if (!isset($ph1ent['mobile']))
				echo $if."<br />".$ph1ent['remote-gateway'];
			else
				echo $if."<br /><strong>" . gettext("Mobile Client") . "</strong>";
?>
		</td>
		<td onclick="fr_toggle(<?=$i?>)" id="frd<?=$i?>">
			<?=$spans?>
			<?php
			if (empty($ph1ent['iketype']) || $ph1ent['iketype'] == "ikev1")
				echo "{$ph1ent['mode']}";
			?>
			<?=$spane?>
		</td>
		<td onclick="fr_toggle(<?=$i?>)" id="frd<?=$i?>">
			<?=$p1_ealgos[$ph1ent['encryption-algorithm']['name']]['name']?>
<?php
			if ($ph1ent['encryption-algorithm']['keylen']) {
				if ($ph1ent['encryption-algorithm']['keylen']=="auto")
					echo " (" . gettext("auto") . ")";
				else
					echo " ({$ph1ent['encryption-algorithm']['keylen']} " . gettext("bits") . ")";
			}
?>
		</td>
		<td>
			<?=$p1_halgos[$ph1ent['hash-algorithm']]?>
		</td>
		<td>
			<?=htmlspecialchars($ph1ent['descr'])?>
		</td>
		<td>
			<?php // TODO: add mouseover behaviour which indicates insert position when moving ?>
			<button class="btn btn-xs btn-default" type="submit" name="move_<?=$i?>" value="move_<?=$i?>"><?=gettext("move selected entries before this")?></button>
			<a class="btn btn-xs btn-primary" href="vpn_ipsec_phase1.php?p1index=<?=$i?>" title="<?=gettext("edit phase1 entry"); ?>">edit</a>
			<button class="btn btn-xs btn-danger" type="submit" name="del_<?=$i?>" value="del_<?=$i?>" title="<?=gettext('delete phase1 entry'); ?>"
					onclick="return confirm('<?=gettext("Do you really want to delete this phase1 and all associated phase2 entries?"); ?>')">delete</button>
<?php if (!isset($ph1ent['mobile'])): ?>
			<a class="btn btn-xs btn-success" href="vpn_ipsec_phase1.php?dup=<?=$i?>" title="<?=gettext("copy phase1 entry"); ?>">copy</a>
<?php endif; ?>
		</td>
	</tr>
	<tr class="<?= $entryStatus ?>">
		<td colspan="2"></td>
		<td colspan="7" class="contains-table">
<?php
			if (isset($_POST["tdph2-{$i}-visible"]))
				$tdph2_visible = htmlspecialchars($_POST["tdph2-{$i}-visible"]);
			else
				$tdph2_visible = 0;
?>
			<input type="hidden" name="tdph2-<?=$i?>-visible" id="tdph2-<?=$i?>-visible" value="<?=$tdph2_visible?>" />
			<div id="shph2but-<?=$i?>" <?=($tdph2_visible == '1' ? 'style="display:none"' : '')?>>
<?php
				$phase2count=0;
				foreach ($a_phase2 as $ph2ent) {
					if ($ph2ent['ikeid'] != $ph1ent['ikeid'])
						continue;
					$phase2count++;
				}
				$fr_prefix = "frp2{$i}";
				$fr_header = $fr_prefix . "header";
?>
				<input type="button" onclick="show_phase2('tdph2-<?=$i?>','shph2but-<?=$i?>')" value="+" /> - <?php printf(gettext("Show %s Phase-2 entries"), $phase2count); ?>
			</div>
			<div id="tdph2-<?=$i?>" <?=($tdph2_visible != '1' ? 'style="display:none"' : '')?>>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th>&nbsp;</th>
							<th>&nbsp;</th>
							<th><?=gettext("Mode"); ?></th>
							<th><?=gettext("Local Subnet"); ?></th>
							<th><?=gettext("Remote Subnet"); ?></th>
							<th><?=gettext("P2 Protocol"); ?></th>
							<th><?=gettext("P2 Transforms"); ?></th>
							<th><?=gettext("P2 Auth Methods"); ?></th>
							<th>&nbsp;</th>
						</tr>
					</thead>
					<tbody>
<?php $j = 0; foreach ($a_phase2 as $ph2index => $ph2ent): ?>
<?php
						if ($ph2ent['ikeid'] != $ph1ent['ikeid'])
							continue;

						$fr_c = $fr_prefix . "c" . $j;
						$fr_d = $fr_prefix . "d" . $j;

						$iconfn = "pass";
						$entryStatus = (isset($ph2ent['disabled']) || isset($ph1ent['disabled']) ? 'disabled' : 'enabled');

						if ($entryStatus == 'disabled')
							$iconfn .= "_d";

?>
						<tr id="<?=$fr_prefix . $j?>" ondblclick="document.location='vpn_ipsec_phase2.php?p2index=<?=$ph2ent['uniqid']?>'" class="<?= $entryStatus ?>">
							<td>
								<input type="checkbox" id="<?=$fr_c?>" name="p2entry[]" value="<?=$ph2index?>" onclick="fr_bgcolor('<?=$j?>', '<?=$fr_prefix?>')" />
							</td>
							<td>
								<button value="togglep2_<?=$ph2index?>" name="togglep2_<?=$ph2index?>" title="<?=gettext("click to toggle enabled/disabled status")?>" class="btn btn-xs btn-default" type="submit"><?= ($entryStatus == 'disabled'? 'enable' : 'disable') ?></button>
							</td>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
								<?=$ph2ent['mode']?>
							</td>
<?php if(($ph2ent['mode'] == "tunnel") or ($ph2ent['mode'] == "tunnel6")): ?>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
								<?=ipsec_idinfo_to_text($ph2ent['localid']); ?>
							</td>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
								<?=ipsec_idinfo_to_text($ph2ent['remoteid']); ?>
							</td>
<?php else: ?>
							<td colspan="2"></td>
<?php endif; ?>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
								<?=$p2_protos[$ph2ent['protocol']]; ?>
							</td>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
<?php
								foreach ($ph2ent['encryption-algorithm-option'] as $k => $ph2ea) {
									if ($k)
										echo ", ";
									echo $p2_ealgos[$ph2ea['name']]['name'];
									if ($ph2ea['keylen']) {
										if ($ph2ea['keylen']=="auto")
											echo " (" . gettext("auto") . ")";
										else
											echo " ({$ph2ea['keylen']} " . gettext("bits") . ")";
									}
								}
?>
							</td>
							<td id="<?=$fr_d?>" onclick="fr_toggle('<?=$j?>', '<?=$fr_prefix?>')">
<?php
								if (!empty($ph2ent['hash-algorithm-option']) && is_array($ph2ent['hash-algorithm-option'])) {
									foreach ($ph2ent['hash-algorithm-option'] as $k => $ph2ha) {
										if ($k)
											echo ", ";
										echo $p2_halgos[$ph2ha];
									}
								}
?>
							</td>
							<td>
								<?php // TODO: add mouseover behaviour which indicates insert position when moving ?>
								<button class="btn btn-xs btn-default" type="submit" name="movep2_<?=$j?>" value="movep2_<?=$j?>"><?=gettext("move selected entries before this")?></button>
								<a class="btn btn-xs btn-primary" href="vpn_ipsec_phase2.php?p2index=<?=$ph2ent['uniqid']?>" title="<?=gettext("edit phase2 entry"); ?>">edit</a>
								<button class="btn btn-xs btn-danger" type="submit" name="delp2_<?=$ph2index?>" value="delp2_<?=$ph2index?>" title="<?=gettext('delete phase2 entry'); ?>"
										onclick="return confirm('<?=gettext("Do you really want to delete this phase2 entry?"); ?>')">delete</button>
								<a class="btn btn-xs btn-success" href="vpn_ipsec_phase2.php?dup=<?=$ph2ent['uniqid']?>" title="<?=gettext("add a new Phase 2 based on this one"); ?>">copy</a>
							</td>
						</tr>
<?php $j++; endforeach; ?>
						<tr>
							<td colspan="8"></td>
							<td>
<?php
							if ($j == 0):
?>
								<img src="/themes/<?= $g['theme']; ?>/images/icons/icon_left_d.gif" width="17" height="17" title="<?=gettext("move selected phase2 entries to end")?>" border="0" alt="move" />
<?php
							else:
?>
								<input onmouseover="fr_insline(<?=$j?>, true, '<?=$fr_prefix?>')" onmouseout="fr_insline(<?=$j?>, false, '<?=$fr_prefix?>')" name="movep2_<?=$j?>" type="image" src="/themes/<?= $g['theme']; ?>/images/icons/icon_left.gif" style="width:17;height:17;border:0" title="<?=gettext("move selected phase2 entries to end")?>" />
<?php
							endif;
?>
								<a href="vpn_ipsec_phase2.php?ikeid=<?=$ph1ent['ikeid']?><?php if (isset($ph1ent['mobile'])) echo "&amp;mobile=true"?>">
									<img src="./themes/<?= $g['theme']; ?>/images/icons/icon_plus.gif" title="<?=gettext("add phase2 entry"); ?>" alt="add" />
								</a>
<?php
							if ($j == 0):
?>
								<img src="/themes/<?= $g['theme']; ?>/images/icons/icon_x_d.gif" width="17" height="17" title="<?=gettext("delete selected phase2 entries")?>" border="0" alt="delete" />
<?php
							else:
?>
								<input name="delp2" type="image" src="/themes/<?= $g['theme']; ?>/images/icons/icon_x.gif" style="width:17;height:17" title="<?=gettext("delete selected phase2 entries")?>" onclick="return confirm('<?=gettext("Do you really want to delete the selected phase2 entries?")?>')" />
<?php
							endif;
?>
							</td>
						</tr>
					</tbody>
				</table>
			</div>
		</td>
	</tr>
<?php
					$i++;
				endforeach;  // $a_phase1 as $ph1ent
?>
					<tr valign="top" id="fr<?=$i?>">
						<td class="list" colspan="8"></td>
						<td class="list nowrap" valign="middle">
							<table border="0" cellspacing="0" cellpadding="1" summary="edit">
								<tr>
									<td>
<?php
									if ($i == 0):
?>
										<img src="/themes/<?= $g['theme']; ?>/images/icons/icon_left_d.gif" width="17" height="17" title="<?=gettext("move selected phase1 entries to end")?>" border="0" alt="move" />
<?php
									else:
?>
										<input onmouseover="fr_insline(<?=$i?>, true)" onmouseout="fr_insline(<?=$i?>, false)" name="move_<?=$i?>" type="image" src="/themes/<?= $g['theme']; ?>/images/icons/icon_left.gif" style="width:17;height:17;border:0" title="<?=gettext("move selected phase1 entries to end")?>" />
<?php
									endif;
?>
									</td>
									<td>
										<a href="vpn_ipsec_phase1.php">
											<img src="/themes/<?= $g['theme']; ?>/images/icons/icon_plus.gif" title="<?=gettext("add new phase1")?>" alt="add" />
										</a>
									</td>
								</tr>
								<tr>
									<td>
<?php
									if ($i == 0):
?>
										<img src="/themes/<?= $g['theme']; ?>/images/icons/icon_x_d.gif" width="17" height="17" title="<?=gettext("delete selected phase1 entries")?>" border="0" alt="delete" />
<?php
									else:
?>
										<input name="del" type="image" src="/themes/<?= $g['theme']; ?>/images/icons/icon_x.gif" style="width:17;height:17" title="<?=gettext("delete selected phase1 entries")?>" onclick="return confirm('<?=gettext("Do you really want to delete the selected phase1 entries?")?>')" />
<?php
									endif;
?>
									</td>
								</tr>
							</table>
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>

</form>

<div class="alert alert-info">
	<strong><?=gettext("Note:")?></strong><br />
	<?=gettext("You can check your IPsec status at"); ?> <a href="diag_ipsec.php"><?=gettext("Status:IPsec"); ?></a>.<br />
	<?=gettext("IPsec Debug Mode can be enabled at"); ?> <a href="vpn_ipsec_settings.php"><?=gettext("VPN:IPsec:Advanced Settings"); ?></a>.<br />
	<?=gettext("IPsec can be set to prefer older SAs at"); ?> <a href="vpn_ipsec_settings.php"><?=gettext("VPN:IPsec:Advanced Settings"); ?></a>.
</div>

<?php include("foot.inc"); ?>
<script type="text/javascript">
//<![CDATA[
function show_phase2(id, buttonid) {
	document.getElementById(buttonid).innerHTML='';
	document.getElementById(id).style.display = "block";
	var visible = id + '-visible';
	document.getElementById(visible).value = "1";
}
//]]>
</script>